aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/backend/catalog/Makefile4
-rw-r--r--src/backend/catalog/genbki.sh17
-rw-r--r--src/backend/postmaster/postmaster.c22
-rw-r--r--src/include/c.h90
-rw-r--r--src/include/miscadmin.h4
-rw-r--r--src/include/pg_config.h.in1058
-rw-r--r--src/include/pg_config_manual.h212
-rw-r--r--src/include/postgres.h3
8 files changed, 743 insertions, 667 deletions
diff --git a/src/backend/catalog/Makefile b/src/backend/catalog/Makefile
index 383775d8476..bf36399daa5 100644
--- a/src/backend/catalog/Makefile
+++ b/src/backend/catalog/Makefile
@@ -2,7 +2,7 @@
#
# Makefile for backend/catalog
#
-# $Header: /cvsroot/pgsql/src/backend/catalog/Makefile,v 1.45 2003/01/14 23:19:34 petere Exp $
+# $Header: /cvsroot/pgsql/src/backend/catalog/Makefile,v 1.46 2003/04/06 22:45:22 petere Exp $
#
#-------------------------------------------------------------------------
@@ -38,7 +38,7 @@ POSTGRES_BKI_SRCS := $(addprefix $(top_srcdir)/src/include/catalog/,\
pg_includes := $(sort -I$(top_srcdir)/src/include -I$(top_builddir)/src/include)
postgres.bki postgres.description: genbki.sh $(POSTGRES_BKI_SRCS) \
- $(top_srcdir)/src/include/postgres_ext.h $(top_builddir)/src/include/pg_config.h
+ $(top_srcdir)/src/include/postgres_ext.h $(top_builddir)/src/include/pg_config_manual.h
CPP='$(CPP)' AWK='$(AWK)' $(SHELL) $< $(BKIOPTS) -o postgres $(pg_includes) $(POSTGRES_BKI_SRCS) --set-version=$(VERSION)
.PHONY: install-data
diff --git a/src/backend/postmaster/postmaster.c b/src/backend/postmaster/postmaster.c
index 694a6e5a73f..0221c64773d 100644
--- a/src/backend/postmaster/postmaster.c
+++ b/src/backend/postmaster/postmaster.c
@@ -37,7 +37,7 @@
*
*
* IDENTIFICATION
- * $Header: /cvsroot/pgsql/src/backend/postmaster/postmaster.c,v 1.309 2003/03/24 22:40:14 tgl Exp $
+ * $Header: /cvsroot/pgsql/src/backend/postmaster/postmaster.c,v 1.310 2003/04/06 22:45:22 petere Exp $
*
* NOTES
*
@@ -143,13 +143,12 @@ char *VirtualHost;
/*
* MaxBackends is the limit on the number of backends we can start.
- * The default is established by configure, but it can be altered at
- * postmaster start with the postmaster's -N switch. Note
- * that a larger MaxBackends value will increase the size of the shared
- * memory area as well as cause the postmaster to grab more kernel
- * semaphores, even if you never actually use that many backends.
+ * Note that a larger MaxBackends value will increase the size of the
+ * shared memory area as well as cause the postmaster to grab more
+ * kernel semaphores, even if you never actually use that many
+ * backends.
*/
-int MaxBackends = DEF_MAXBACKENDS;
+int MaxBackends;
/*
* ReservedBackends is the number of backends reserved for superuser use.
@@ -160,7 +159,7 @@ int MaxBackends = DEF_MAXBACKENDS;
* can make new connections" --- pre-existing superuser connections don't
* count against the limit.
*/
-int ReservedBackends = 2;
+int ReservedBackends;
static char *progname = (char *) NULL;
@@ -892,7 +891,7 @@ usage(const char *progname)
#ifdef USE_ASSERT_CHECKING
printf(gettext(" -A 1|0 enable/disable run-time assert checking\n"));
#endif
- printf(gettext(" -B NBUFFERS number of shared buffers (default %d)\n"), DEF_NBUFFERS);
+ printf(gettext(" -B NBUFFERS number of shared buffers\n"));
printf(gettext(" -c NAME=VALUE set run-time parameter\n"));
printf(gettext(" -d 1-5 debugging level\n"));
printf(gettext(" -D DATADIR database directory\n"));
@@ -903,10 +902,9 @@ usage(const char *progname)
#ifdef USE_SSL
printf(gettext(" -l enable SSL connections\n"));
#endif
- printf(gettext(" -N MAX-CONNECT maximum number of allowed connections (default %d)\n"),
- DEF_MAXBACKENDS);
+ printf(gettext(" -N MAX-CONNECT maximum number of allowed connections\n"));
printf(gettext(" -o OPTIONS pass 'OPTIONS' to each backend server\n"));
- printf(gettext(" -p PORT port number to listen on (default %d)\n"), DEF_PGPORT);
+ printf(gettext(" -p PORT port number to listen on\n"));
printf(gettext(" -S silent mode (start in background without logging output)\n"));
printf(gettext(" --help show this help, then exit\n"));
printf(gettext(" --version output version information, then exit\n"));
diff --git a/src/include/c.h b/src/include/c.h
index 0129098d451..89d8012ba64 100644
--- a/src/include/c.h
+++ b/src/include/c.h
@@ -12,7 +12,7 @@
* Portions Copyright (c) 1996-2002, PostgreSQL Global Development Group
* Portions Copyright (c) 1994, Regents of the University of California
*
- * $Id: c.h,v 1.136 2003/04/04 20:42:13 momjian Exp $
+ * $Id: c.h,v 1.137 2003/04/06 22:45:23 petere Exp $
*
*-------------------------------------------------------------------------
*/
@@ -51,6 +51,8 @@
*/
#include "pg_config.h"
+#include "pg_config_manual.h"
+#include "pg_config_os.h"
#include "postgres_ext.h"
#include <stdio.h>
@@ -708,8 +710,7 @@ off_t ftello(FILE *stream);
/*
* Provide prototypes for routines not present in a particular machine's
- * standard C library. It'd be better to put these in pg_config.h, but
- * in pg_config.h we haven't yet included anything that defines size_t...
+ * standard C library.
*/
#if !HAVE_DECL_SNPRINTF
@@ -727,4 +728,87 @@ extern int vsnprintf(char *str, size_t count, const char *fmt, va_list args);
#define memmove(d, s, c) bcopy(s, d, c)
#endif
+#ifndef DLLIMPORT
+#define DLLIMPORT /* no special DLL markers on most ports */
+#endif
+
+/*
+ * The following is used as the arg list for signal handlers. Any ports
+ * that take something other than an int argument should override this in
+ * their pg_config_os.h file. Note that variable names are required
+ * because it is used in both the prototypes as well as the definitions.
+ * Note also the long name. We expect that this won't collide with
+ * other names causing compiler warnings.
+ */
+
+#ifndef SIGNAL_ARGS
+#define SIGNAL_ARGS int postgres_signal_arg
+#endif
+
+/*
+ * Default "extern" declarations or macro substitutes for library routines.
+ * When necessary, these routines are provided by files in src/port/.
+ */
+#ifndef HAVE_FSEEKO
+#define fseeko(a, b, c) fseek((a), (b), (c))
+#define ftello(a) ftell((a))
+#endif
+
+#ifndef HAVE_ISINF
+extern int isinf(double x);
+#endif
+
+#ifndef HAVE_GETHOSTNAME
+extern int gethostname(char *name, int namelen);
+#endif
+
+#ifndef HAVE_INET_ATON
+# include <netinet/in.h>
+# include <arpa/inet.h>
+extern int inet_aton(const char *cp, struct in_addr * addr);
+#endif
+
+/*
+ * When there is no sigsetjmp, its functionality is provided by plain
+ * setjmp. Incidentally, nothing provides setjmp's functionality in
+ * that case.
+ */
+#ifndef HAVE_SIGSETJMP
+# define sigjmp_buf jmp_buf
+# define sigsetjmp(x,y) setjmp(x)
+# define siglongjmp longjmp
+#endif
+
+#ifndef HAVE_STRCASECMP
+extern int strcasecmp(char *s1, char *s2);
+#endif
+
+#ifndef HAVE_STRDUP
+extern char *strdup(char const *);
+#endif
+
+#ifndef HAVE_RANDOM
+extern long random(void);
+#endif
+
+#ifndef HAVE_SRANDOM
+extern void srandom(unsigned int seed);
+#endif
+
+#if defined(HAVE_FDATASYNC) && !HAVE_DECL_FDATASYNC
+extern int fdatasync(int fildes);
+#endif
+
+/* If strtoq() exists, rename it to the more standard strtoll() */
+#if defined(HAVE_LONG_LONG_INT_64) && !defined(HAVE_STRTOLL) && defined(HAVE_STRTOQ)
+# define strtoll strtoq
+# define HAVE_STRTOLL 1
+#endif
+
+/* If strtouq() exists, rename it to the more standard strtoull() */
+#if defined(HAVE_LONG_LONG_INT_64) && !defined(HAVE_STRTOULL) && defined(HAVE_STRTOUQ)
+# define strtoull strtouq
+# define HAVE_STRTOULL 1
+#endif
+
#endif /* C_H */
diff --git a/src/include/miscadmin.h b/src/include/miscadmin.h
index e44d0fbad30..d4bd255cb0b 100644
--- a/src/include/miscadmin.h
+++ b/src/include/miscadmin.h
@@ -12,7 +12,7 @@
* Portions Copyright (c) 1996-2002, PostgreSQL Global Development Group
* Portions Copyright (c) 1994, Regents of the University of California
*
- * $Id: miscadmin.h,v 1.117 2003/03/20 04:51:44 momjian Exp $
+ * $Id: miscadmin.h,v 1.118 2003/04/06 22:45:23 petere Exp $
*
* NOTES
* some of the information in this file should be moved to
@@ -171,8 +171,10 @@ extern bool NetServer;
extern bool EnableSSL;
extern bool SilentMode;
extern int MaxBackends;
+#define DEF_MAXBACKENDS 32
extern int ReservedBackends;
extern DLLIMPORT int NBuffers;
+#define DEF_NBUFFERS (DEF_MAXBACKENDS > 8 ? DEF_MAXBACKENDS * 2 : 16)
extern int PostPortNumber;
extern int Unix_socket_permissions;
extern char *Unix_socket_group;
diff --git a/src/include/pg_config.h.in b/src/include/pg_config.h.in
index d135e815a93..33a20e3cb94 100644
--- a/src/include/pg_config.h.in
+++ b/src/include/pg_config.h.in
@@ -1,802 +1,580 @@
-/*
- * PostgreSQL configuration-settings file.
- *
- * pg_config.h.in is processed by configure to produce pg_config.h.
- *
- * If you want to modify any of the tweakable settings in Part 2
- * of this file, you can do it in pg_config.h.in before running configure,
- * or in pg_config.h afterwards. Of course, if you edit pg_config.h, then your
- * changes will be overwritten the next time you run configure.
- *
- * $Id: pg_config.h.in,v 1.43 2003/04/02 00:49:28 tgl Exp $
- */
-
-#ifndef PG_CONFIG_H
-#define PG_CONFIG_H
-
-
-/*
- *------------------------------------------------------------------------
- * Part 1: feature symbols and limits that are set by configure based on
- * user-supplied switches. This is first so that stuff in Part 2 can
- * depend on these values.
- *
- * Beware of "fixing" configure-time mistakes by editing these values,
- * since configure may have inserted the settings in other files as well
- * as here. Best to rerun configure if you forgot --enable-integer-datetimes
- * or whatever.
- *------------------------------------------------------------------------
- */
-
-/* The version number is actually hard-coded into configure.in */
-#undef PG_VERSION
-/* A canonical string containing the version number, platform, and C compiler */
-#undef PG_VERSION_STR
+/* src/include/pg_config.h.in. Generated from configure.in by autoheader. */
-/* Set to 1 if you want 64-bit integer timestamp and interval support (--enable-integer-datetimes) */
-#undef USE_INTEGER_DATETIMES
+/* Define to the type of arg 1 of 'accept' */
+#undef ACCEPT_TYPE_ARG1
-/* Set to 1 if you want single-byte recode (--enable-recode) */
-#undef CYR_RECODE
+/* Define to the type of arg 2 of 'accept' */
+#undef ACCEPT_TYPE_ARG2
-/* Set to 1 if you want ASSERT checking (--enable-cassert) */
-#undef USE_ASSERT_CHECKING
+/* Define to the type of arg 3 of 'accept' */
+#undef ACCEPT_TYPE_ARG3
-/* Define to build with Kerberos 4 support (--with-krb4[=DIR]) */
-#undef KRB4
+/* The alignment requirement of a `double'. */
+#undef ALIGNOF_DOUBLE
-/* Define to build with Kerberos 5 support (--with-krb5[=DIR]) */
-#undef KRB5
+/* The alignment requirement of a `int'. */
+#undef ALIGNOF_INT
-/* Kerberos name of the Postgres service principal (--with-krb-srvnam=NAME) */
-#undef PG_KRB_SRVNAM
+/* The alignment requirement of a `long'. */
+#undef ALIGNOF_LONG
-/* Define to build with (Open)SSL support (--with-openssl[=DIR]) */
-#undef USE_SSL
+/* The alignment requirement of a `long long int'. */
+#undef ALIGNOF_LONG_LONG_INT
-/* Define to build with PAM Support */
-#undef USE_PAM
+/* The alignment requirement of a `short'. */
+#undef ALIGNOF_SHORT
-/*
- * DEF_PGPORT is the TCP port number on which the Postmaster listens and
- * which clients will try to connect to. This is just a default value;
- * it can be overridden at postmaster or client startup. It's awfully
- * convenient if your clients have the right default compiled in, though.
- * (--with-pgport=PORTNUM)
- */
+/* Define to 1 if you want single-byte recode support. (--enable-recode) */
+#undef CYR_RECODE
+
+/* Define to the default TCP port number on which the server listens and to
+ which clients will try to connect to. This can be overridden at run-time,
+ but it's convenient if your clients have the right default compiled in.
+ (--with-pgport=PORTNUM) */
#undef DEF_PGPORT
-/* ... and once more as a string constant instead */
-#undef DEF_PGPORT_STR
-/*
- * Default soft limit on number of backend server processes per postmaster;
- * this is just the default setting for the postmaster's -N switch.
- * (--with-maxbackends=N)
- */
-#undef DEF_MAXBACKENDS
+/* Define to the default TCP port number as string constant. */
+#undef DEF_PGPORT_STR
-/* --enable-nls */
+/* Define to 1 if you want National Language Support. (--enable-nls) */
#undef ENABLE_NLS
-/* location of locale files */
-#undef LOCALEDIR
-
+/* Define to 1 if gettimeofday() takes only 1 argument. */
+#undef GETTIMEOFDAY_1ARG
-/*
- *------------------------------------------------------------------------
- * Part 2: feature symbols and limits that are user-configurable, but
- * only by editing this file ... there's no configure support for them.
- *
- * Editing this file and doing a full rebuild (and an initdb if noted)
- * should be sufficient to change any of these.
- *------------------------------------------------------------------------
- */
-
-/*
- * Default number of buffers in shared buffer pool (each of size BLCKSZ).
- * This is just the default setting for the postmaster's -B switch.
- * Perhaps it ought to be configurable from a configure switch.
- * NOTE: default setting corresponds to the minimum number of buffers
- * that postmaster.c will allow for the default MaxBackends value.
- */
-#define DEF_NBUFFERS (DEF_MAXBACKENDS > 8 ? DEF_MAXBACKENDS * 2 : 16)
-
-/*
- * Size of a disk block --- this also limits the size of a tuple.
- * You can set it bigger if you need bigger tuples (although TOAST
- * should reduce the need to have large tuples, since fields can now
- * be spread across multiple tuples).
- *
- * BLCKSZ must be a power of 2.
- * The maximum possible value of BLCKSZ is currently 2^15 (32768).
- * This is determined by the 15-bit widths of the lp_off and lp_len
- * fields in ItemIdData (see include/storage/itemid.h).
- *
- * CAUTION: changing BLCKSZ requires an initdb.
- */
-#define BLCKSZ 8192
-
-/*
- * RELSEG_SIZE is the maximum number of blocks allowed in one disk file.
- * Thus, the maximum size of a single file is RELSEG_SIZE * BLCKSZ;
- * relations bigger than that are divided into multiple files.
- *
- * CAUTION: RELSEG_SIZE * BLCKSZ must be less than your OS' limit on file
- * size. This is typically 2Gb or 4Gb in a 32-bit operating system. By
- * default, we make the limit 1Gb to avoid any possible integer-overflow
- * problems within the OS. A limit smaller than necessary only means we
- * divide a large relation into more chunks than necessary, so it seems
- * best to err in the direction of a small limit. (Besides, a power-of-2
- * value saves a few cycles in md.c.)
- *
- * CAUTION: changing RELSEG_SIZE requires an initdb.
- */
-#define RELSEG_SIZE (0x40000000 / BLCKSZ)
-
-/*
- * Maximum number of columns in an index and maximum number of arguments
- * to a function. They must be the same value.
- *
- * The minimum value is 8 (index creation uses 8-argument functions).
- * There is no specific upper limit, although large values will waste
- * system-table space and processing time.
- *
- * CAUTION: changing these requires an initdb.
- *
- * BTW: if you need to call dynamically-loaded old-style C functions that
- * have more than 16 arguments, you will also need to add cases to the
- * switch statement in fmgr_oldstyle() in src/backend/utils/fmgr/fmgr.c.
- * But consider converting such functions to new-style instead...
- */
-#define INDEX_MAX_KEYS 32
-#define FUNC_MAX_ARGS INDEX_MAX_KEYS
-
-/*
- * Define this to make libpgtcl's "pg_result -assign" command process C-style
- * backslash sequences in returned tuple data and convert Postgres array
- * attributes into Tcl lists. CAUTION: this conversion is *wrong* unless
- * you install the routines in contrib/string/string_io to make the backend
- * produce C-style backslash sequences in the first place.
- */
-/* #define TCL_ARRAYS */
-
-/*
- * User locks are handled totally on the application side as long term
- * cooperative locks which extend beyond the normal transaction boundaries.
- * Their purpose is to indicate to an application that someone is `working'
- * on an item. Define this flag to enable user locks. You will need the
- * loadable module user-locks.c to use this feature.
- */
-#define USER_LOCKS
-
-/*
- * Define this if you want psql to _always_ ask for a username and a password
- * for password authentication.
- */
-/* #define PSQL_ALWAYS_GET_PASSWORDS */
-
-/*
- * Define this if you want to allow the lo_import and lo_export SQL functions
- * to be executed by ordinary users. By default these functions are only
- * available to the Postgres superuser. CAUTION: these functions are
- * SECURITY HOLES since they can read and write any file that the Postgres
- * backend has permission to access. If you turn this on, don't say we
- * didn't warn you.
- */
-/* #define ALLOW_DANGEROUS_LO_FUNCTIONS */
-
-/*
- * MAXPGPATH: standard size of a pathname buffer in Postgres (hence,
- * maximum usable pathname length is one less).
- *
- * We'd use a standard system header symbol for this, if there weren't
- * so many to choose from: MAXPATHLEN, _POSIX_PATH_MAX, MAX_PATH, PATH_MAX
- * are all defined by different "standards", and often have different
- * values on the same platform! So we just punt and use a reasonably
- * generous setting here.
- */
-#define MAXPGPATH 1024
-
-/*
- * DEFAULT_MAX_EXPR_DEPTH: default value of max_expr_depth SET variable.
- */
-#define DEFAULT_MAX_EXPR_DEPTH 10000
-
-/*
- * PG_SOMAXCONN: maximum accept-queue length limit passed to listen(2).
- * You'd think we should use SOMAXCONN from <sys/socket.h>, but on many
- * systems that symbol is much smaller than the kernel's actual limit.
- * In any case, this symbol need be twiddled only if you have a kernel
- * that refuses large limit values, rather than silently reducing the
- * value to what it can handle (which is what most if not all Unixen do).
- */
-#define PG_SOMAXCONN 10000
-
-/*
- * You can try changing this if you have a machine with bytes of another
- * size, but no guarantee...
- */
-#define BITS_PER_BYTE 8
-
-/*
- * Define this if your operating system supports AF_UNIX family sockets.
- */
-#if !defined(__QNX__) && !defined(__BEOS__)
-# define HAVE_UNIX_SOCKETS 1
+#ifdef GETTIMEOFDAY_1ARG
+# define gettimeofday(a,b) gettimeofday(a)
#endif
-/*
- * This is the default directory in which AF_UNIX socket files are placed.
- * Caution: changing this risks breaking your existing client applications,
- * which are likely to continue to look in the old directory. But if you
- * just hate the idea of sockets in /tmp, here's where to twiddle it.
- * You can also override this at runtime with the postmaster's -k switch.
- */
-#define DEFAULT_PGSOCKET_DIR "/tmp"
-
-
-/*
- *------------------------------------------------------------------------
- * These hand-configurable symbols are for enabling debugging code,
- * not for controlling user-visible features or resource limits.
- *------------------------------------------------------------------------
- */
-
-/* Define this to cause pfree()'d memory to be cleared immediately,
- * to facilitate catching bugs that refer to already-freed values.
- * XXX For 7.1 development, define this automatically if --enable-cassert.
- * In the long term it probably doesn't need to be on by default.
- */
-#ifdef USE_ASSERT_CHECKING
-#define CLOBBER_FREED_MEMORY
-#endif
+/* Define to 1 if you have the `atexit' function. */
+#undef HAVE_ATEXIT
-/* Define this to check memory allocation errors (scribbling on more
- * bytes than were allocated).
- * XXX For 7.1 development, define this automatically if --enable-cassert.
- * In the long term it probably doesn't need to be on by default.
- */
-#ifdef USE_ASSERT_CHECKING
-#define MEMORY_CONTEXT_CHECKING
-#endif
+/* Define to 1 if you have the `cbrt' function. */
+#undef HAVE_CBRT
-/* Define this to force all parse and plan trees to be passed through
- * copyObject(), to facilitate catching errors and omissions in copyObject().
- */
-/* #define COPY_PARSE_PLAN_TREES */
-
-/* Enable debugging print statements for lock-related operations. */
-/* #define LOCK_DEBUG */
-
-/*
- * Other debug #defines (documentation, anyone?)
- */
-/* #define IPORTAL_DEBUG */
-/* #define HEAPDEBUGALL */
-/* #define ISTRATDEBUG */
-/* #define ACLDEBUG */
-/* #define RTDEBUG */
-/* #define GISTDEBUG */
-
-/*
- * defining unsafe floats will make float4 and float8 ops faster
- * by suppressing overflow/underflow checks.
- */
-/* #define UNSAFE_FLOATS */
-
-
-/*
- *------------------------------------------------------------------------
- * Part 3: system configuration information that is auto-detected by
- * configure. In theory you shouldn't have to touch any of this stuff
- * by hand. In the real world, configure might get it wrong...
- *------------------------------------------------------------------------
- */
-
-/* Define const as empty if your compiler doesn't grok const. */
-#undef const
+/* Define to 1 if you have the `class' function. */
+#undef HAVE_CLASS
-/* Define as your compiler's spelling of "inline", or empty if no inline. */
-#undef inline
+/* Define to 1 if you have the <crypt.h> header file. */
+#undef HAVE_CRYPT_H
-/* Define as empty if the C compiler doesn't understand "signed". */
-#undef signed
+/* Define to 1 if you have the declaration of `fdatasync', and to 0 if you
+ don't. */
+#undef HAVE_DECL_FDATASYNC
-/* Define as empty if the C compiler doesn't understand "volatile". */
-#undef volatile
+/* Define to 1 if you have the declaration of `snprintf', and to 0 if you
+ don't. */
+#undef HAVE_DECL_SNPRINTF
-/* Define to 1 to make fseeko visible on some hosts. */
-#undef _LARGEFILE_SOURCE
+/* Define to 1 if you have the declaration of `vsnprintf', and to 0 if you
+ don't. */
+#undef HAVE_DECL_VSNPRINTF
-/* Define for large files, on AIX-style hosts. */
-#undef _LARGE_FILES
+/* Define to 1 if you have the <dld.h> header file. */
+#undef HAVE_DLD_H
-/* Number of bits in a file offset, on hosts where this is settable. */
-#undef _FILE_OFFSET_BITS
+/* Define to 1 if you have the `dlopen' function. */
+#undef HAVE_DLOPEN
-/* Define to 1 if fseeko (and presumably ftello) exists and is declared. */
-#undef HAVE_FSEEKO
+/* Define to 1 if you have the <editline/history.h> header file. */
+#undef HAVE_EDITLINE_HISTORY_H
-/* Define if your cpp understands the ANSI stringizing operators in macros */
-#undef HAVE_STRINGIZE
+/* Define to 1 if you have the <editline/readline.h> header file. */
+#undef HAVE_EDITLINE_READLINE_H
-/* Set to 1 if you have <crypt.h> */
-#undef HAVE_CRYPT_H
+/* Define to 1 if you have the <endian.h> header file. */
+#undef HAVE_ENDIAN_H
-/* Set to 1 if you have <dld.h> */
-#undef HAVE_DLD_H
+/* Define to 1 if you have the `fcvt' function. */
+#undef HAVE_FCVT
-/* Set to 1 if you have <endian.h> */
-#undef HAVE_ENDIAN_H
+/* Define to 1 if you have the `fdatasync' function. */
+#undef HAVE_FDATASYNC
+
+/* Define to 1 if you have finite(). */
+#undef HAVE_FINITE
-/* Set to 1 if you have <fp_class.h> */
+/* Define to 1 if you have the `fpclass' function. */
+#undef HAVE_FPCLASS
+
+/* Define to 1 if you have the `fp_class' function. */
+#undef HAVE_FP_CLASS
+
+/* Define to 1 if you have the `fp_class_d' function. */
+#undef HAVE_FP_CLASS_D
+
+/* Define to 1 if you have the <fp_class.h> header file. */
#undef HAVE_FP_CLASS_H
-/* Set to 1 if you have <getopt.h> */
+/* Define to 1 if fseeko (and presumably ftello) exists and is declared. */
+#undef HAVE_FSEEKO
+
+/* Define to 1 if you have the `getaddrinfo' function. */
+#undef HAVE_GETADDRINFO
+
+/* Define to 1 if you have the `gethostname' function. */
+#undef HAVE_GETHOSTNAME
+
+/* Define to 1 if you have the <getopt.h> header file. */
#undef HAVE_GETOPT_H
-/* Set to 1 if you have <history.h> */
+/* Define to 1 if you have the `getopt_long' function. */
+#undef HAVE_GETOPT_LONG
+
+/* Define to 1 if you have the `getpeereid' function. */
+#undef HAVE_GETPEEREID
+
+/* Define to 1 if you have the `getrusage' function. */
+#undef HAVE_GETRUSAGE
+
+/* Define to 1 if you have the <history.h> header file. */
#undef HAVE_HISTORY_H
-/* Set to 1 if you have <ieeefp.h> */
+/* Define to 1 if you have the <ieeefp.h> header file. */
#undef HAVE_IEEEFP_H
-/* Set to 1 if you have <poll.h> */
-#undef HAVE_POLL_H
+/* Define to 1 if you have the `inet_aton' function. */
+#undef HAVE_INET_ATON
-/* Set to 1 if you have <sys/poll.h> */
-#undef HAVE_SYS_POLL_H
+/* Define to 1 if the system has the type `int64'. */
+#undef HAVE_INT64
-/* Set to 1 if you have <netinet/tcp.h> */
-#undef HAVE_NETINET_TCP_H
+/* Define to 1 if the system has the type `int8'. */
+#undef HAVE_INT8
-/* Set to 1 if you have <pam/pam_appl.h> */
-#undef HAVE_PAM_PAM_APPL_H
+/* Define to 1 if you have the <inttypes.h> header file. */
+#undef HAVE_INTTYPES_H
-/* Set to 1 if you have <readline.h> */
-#undef HAVE_READLINE_H
+/* Define to 1 if you have the global variable 'int optreset'. */
+#undef HAVE_INT_OPTRESET
-/* Set to 1 if you have <readline/history.h> */
-#undef HAVE_READLINE_HISTORY_H
+/* Define to 1 if you have the global variable 'int timezone'. */
+#undef HAVE_INT_TIMEZONE
-/* Set to 1 if you have <readline/readline.h> */
-#undef HAVE_READLINE_READLINE_H
+/* Define to 1 if you have support for IPv6. */
+#undef HAVE_IPV6
-/* Set to 1 if you have <editline/history.h> */
-#undef HAVE_EDITLINE_HISTORY_H
+/* Define to 1 if you have isinf(). */
+#undef HAVE_ISINF
-/* Set to 1 if you have <editline/readline.h> */
-#undef HAVE_EDITLINE_READLINE_H
+/* Define to 1 if you have the <kernel/image.h> header file. */
+#undef HAVE_KERNEL_IMAGE_H
-/* Set to 1 if you have <security/pam_appl.h> */
-#undef HAVE_SECURITY_PAM_APPL_H
+/* Define to 1 if you have the <kernel/OS.h> header file. */
+#undef HAVE_KERNEL_OS_H
-/* Set to 1 if you have <sys/ipc.h> */
-#undef HAVE_SYS_IPC_H
+/* Define to 1 if `e_data' is member of `krb5_error'. */
+#undef HAVE_KRB5_ERROR_E_DATA
-/* Set to 1 if you have <sys/select.h> */
-#undef HAVE_SYS_SELECT_H
+/* Define to 1 if `text.data' is member of `krb5_error'. */
+#undef HAVE_KRB5_ERROR_TEXT_DATA
-/* Set to 1 if you have <sys/un.h> */
-#undef HAVE_SYS_UN_H
+/* Define to 1 if `client' is member of `krb5_ticket'. */
+#undef HAVE_KRB5_TICKET_CLIENT
-/* Set to 1 if you have <sys/sem.h> */
-#undef HAVE_SYS_SEM_H
+/* Define to 1 if `enc_part2' is member of `krb5_ticket'. */
+#undef HAVE_KRB5_TICKET_ENC_PART2
-/* Set to 1 if you have <sys/shm.h> */
-#undef HAVE_SYS_SHM_H
+/* Define to 1 if you have the `bind' library (-lbind). */
+#undef HAVE_LIBBIND
-/* Set to 1 if you have support for IPv6 */
-#undef HAVE_IPV6
+/* Define to 1 if you have the `BSD' library (-lBSD). */
+#undef HAVE_LIBBSD
-/* Set to 1 if you have <kernel/OS.h> */
-#undef HAVE_KERNEL_OS_H
+/* Define to 1 if you have the `compat' library (-lcompat). */
+#undef HAVE_LIBCOMPAT
-/* Set to 1 if you have <SupportDefs.h> */
-#undef HAVE_SUPPORTDEFS_H
+/* Define to 1 if you have the `crypto' library (-lcrypto). */
+#undef HAVE_LIBCRYPTO
-/* Set to 1 if you have <kernel/image.h> */
-#undef HAVE_KERNEL_IMAGE_H
+/* Define to 1 if you have the `cygipc' library (-lcygipc). */
+#undef HAVE_LIBCYGIPC
-/* Set to 1 if you have <termios.h> */
-#undef HAVE_TERMIOS_H
+/* Define to 1 if you have the `des' library (-ldes). */
+#undef HAVE_LIBDES
-/* Set to 1 if you have <utime.h> */
-#undef HAVE_UTIME_H
+/* Define to 1 if you have the `dl' library (-ldl). */
+#undef HAVE_LIBDL
-/* Set to 1 if you have <sys/pstat.h> */
-#undef HAVE_SYS_PSTAT_H
+/* Define to 1 if you have the `dld' library (-ldld). */
+#undef HAVE_LIBDLD
-/* Define to 1 if you have strings.h */
-#undef HAVE_STRINGS_H
+/* Define to 1 if you have the `gen' library (-lgen). */
+#undef HAVE_LIBGEN
-/* Define if you have the setproctitle function. */
-#undef HAVE_SETPROCTITLE
+/* Define to 1 if you have the `IPC' library (-lIPC). */
+#undef HAVE_LIBIPC
-/* Define if you have the pstat function. */
-#undef HAVE_PSTAT
+/* Define to 1 if you have the `krb' library (-lkrb). */
+#undef HAVE_LIBKRB
-/* Define if the PS_STRINGS thing exists. */
-#undef HAVE_PS_STRINGS
+/* Define to 1 if you have the `lc' library (-llc). */
+#undef HAVE_LIBLC
-/* Define if you have the stricmp function. */
-#undef HAVE_STRICMP
+/* Define to 1 if you have the `ld' library (-lld). */
+#undef HAVE_LIBLD
-/* Set to 1 if you have <pwd.h> */
-#undef HAVE_PWD_H
+/* Define to 1 if you have the `m' library (-lm). */
+#undef HAVE_LIBM
-/* Set to 1 if you have gettimeofday(a) instead of gettimeofday(a,b) */
-#undef GETTIMEOFDAY_1ARG
+/* Define to 1 if you have the `nsl' library (-lnsl). */
+#undef HAVE_LIBNSL
-#ifdef GETTIMEOFDAY_1ARG
-# define gettimeofday(a,b) gettimeofday(a)
-#endif
+/* Define to 1 if you have the `pam' library (-lpam). */
+#undef HAVE_LIBPAM
-/* Set to 1 if you have snprintf() in the C library */
-#undef HAVE_SNPRINTF
+/* Define to 1 if you have the `PW' library (-lPW). */
+#undef HAVE_LIBPW
-/* Set to 1 if your standard system headers declare snprintf() */
-#undef HAVE_DECL_SNPRINTF
+/* Define if you have a function readline library */
+#undef HAVE_LIBREADLINE
-/* Set to 1 if you have vsnprintf() in the C library */
-#undef HAVE_VSNPRINTF
+/* Define to 1 if you have the `resolv' library (-lresolv). */
+#undef HAVE_LIBRESOLV
-/* Set to 1 if your standard system headers declare vsnprintf() */
-#undef HAVE_DECL_VSNPRINTF
+/* Define to 1 if you have the `socket' library (-lsocket). */
+#undef HAVE_LIBSOCKET
-/* Set to 1 if you have strerror() */
-#undef HAVE_STRERROR
+/* Define to 1 if you have the `ssl' library (-lssl). */
+#undef HAVE_LIBSSL
-/* Set to 1 if you have isinf() */
-#undef HAVE_ISINF
+/* Define to 1 if you have the `unix' library (-lunix). */
+#undef HAVE_LIBUNIX
-/*
- * These are all related to port/isinf.c
- */
-#undef HAVE_FPCLASS
-#undef HAVE_FP_CLASS
-#undef HAVE_FP_CLASS_H
-#undef HAVE_FP_CLASS_D
-#undef HAVE_CLASS
+/* Define to 1 if you have the `util' library (-lutil). */
+#undef HAVE_LIBUTIL
-/* Set to 1 if you have getaddrinfo() */
-#undef HAVE_GETADDRINFO
+/* Define to 1 if you have the `z' library (-lz). */
+#undef HAVE_LIBZ
-/* Set to 1 if you have gethostname() */
-#undef HAVE_GETHOSTNAME
+/* Define to 1 if constants of type 'long long int' should have the suffix LL.
+ */
+#undef HAVE_LL_CONSTANTS
-/* Set to 1 if you have getpeereid() */
-#undef HAVE_GETPEEREID
+/* Define to 1 if `long int' works and is 64 bits. */
+#undef HAVE_LONG_INT_64
-/* Set to 1 if struct tm has a tm_zone member */
-#undef HAVE_TM_ZONE
+/* Define to 1 if `long long int' works and is 64 bits. */
+#undef HAVE_LONG_LONG_INT_64
-/* Set to 1 if you have int timezone.
- * NOTE: if both tm_zone and a global timezone variable exist,
- * using the tm_zone field should probably be preferred,
- * since global variables are inherently not thread-safe.
- */
-#undef HAVE_INT_TIMEZONE
+/* Define to 1 if you have the `memmove' function. */
+#undef HAVE_MEMMOVE
-/* Set to 1 if you have cbrt() */
-#undef HAVE_CBRT
+/* Define to 1 if you have the <memory.h> header file. */
+#undef HAVE_MEMORY_H
-/* Set to 1 if you have inet_aton() */
-#undef HAVE_INET_ATON
+/* Define to 1 if you have the <netinet/in.h> header file. */
+#undef HAVE_NETINET_IN_H
-/* Set to 1 if you have fcvt() */
-#undef HAVE_FCVT
+/* Define to 1 if you have the <netinet/tcp.h> header file. */
+#undef HAVE_NETINET_TCP_H
-/* Set to 1 if you have rint() */
-#undef HAVE_RINT
+/* Define to 1 if you have the `on_exit' function. */
+#undef HAVE_ON_EXIT
-/* Set to 1 if you have finite() */
-#undef HAVE_FINITE
+/* Define to 1 if you have the <pam/pam_appl.h> header file. */
+#undef HAVE_PAM_PAM_APPL_H
-/* Set to 1 if you have memmove() */
-#undef HAVE_MEMMOVE
+/* Define to 1 if you have the `poll' function. */
+#undef HAVE_POLL
-/* Set to 1 if you have sigsetjmp() */
-#undef HAVE_SIGSETJMP
+/* Define to 1 if you have the <poll.h> header file. */
+#undef HAVE_POLL_H
-/* Set to 1 if you have sysconf() */
-#undef HAVE_SYSCONF
+/* Define to 1 if you have the POSIX signal interface. */
+#undef HAVE_POSIX_SIGNALS
-/* Set to 1 if you have getrusage() */
-#undef HAVE_GETRUSAGE
+/* Define to 1 if you have the `pstat' function. */
+#undef HAVE_PSTAT
-/* Set to 1 if you have waitpid() */
-#undef HAVE_WAITPID
+/* Define to 1 if the PS_STRINGS thing exists. */
+#undef HAVE_PS_STRINGS
-/* Set to 1 if you have setsid() */
+/* Define to 1 if you have the <pwd.h> header file. */
+#undef HAVE_PWD_H
+
+/* Define to 1 if you have the `random' function. */
+#undef HAVE_RANDOM
+
+/* Define to 1 if you have the <readline.h> header file. */
+#undef HAVE_READLINE_H
+
+/* Define to 1 if you have the <readline/history.h> header file. */
+#undef HAVE_READLINE_HISTORY_H
+
+/* Define to 1 if you have the <readline/readline.h> header file. */
+#undef HAVE_READLINE_READLINE_H
+
+/* Define to 1 if you have the `replace_history_entry' function. */
+#undef HAVE_REPLACE_HISTORY_ENTRY
+
+/* Define to 1 if you have the `rint' function. */
+#undef HAVE_RINT
+
+/* Define to 1 if you have the global variable
+ 'rl_completion_append_character'. */
+#undef HAVE_RL_COMPLETION_APPEND_CHARACTER
+
+/* Define to 1 if you have the `rl_completion_matches' function. */
+#undef HAVE_RL_COMPLETION_MATCHES
+
+/* Define to 1 if you have the `rl_filename_completion_function' function. */
+#undef HAVE_RL_FILENAME_COMPLETION_FUNCTION
+
+/* Define to 1 if you have the <security/pam_appl.h> header file. */
+#undef HAVE_SECURITY_PAM_APPL_H
+
+/* Define to 1 if you have the `setproctitle' function. */
+#undef HAVE_SETPROCTITLE
+
+/* Define to 1 if you have the `setsid' function. */
#undef HAVE_SETSID
-/* Set to 1 if you have sigprocmask() */
+/* Define to 1 if you have the `sigprocmask' function. */
#undef HAVE_SIGPROCMASK
-/* Set to 1 if you have sigprocmask() */
+/* Define to 1 if you have sigsetjmp(). */
+#undef HAVE_SIGSETJMP
+
+/* Define to 1 if the system has the type `sig_atomic_t'. */
+#undef HAVE_SIG_ATOMIC_T
+
+/* Define to 1 if you have the `snprintf' function. */
+#undef HAVE_SNPRINTF
+
+/* Define to 1 if you have the `srandom' function. */
+#undef HAVE_SRANDOM
+
+/* Define to 1 if you have the <stdint.h> header file. */
+#undef HAVE_STDINT_H
+
+/* Define to 1 if you have the <stdlib.h> header file. */
+#undef HAVE_STDLIB_H
+
+/* Define to 1 if you have the `strcasecmp' function. */
#undef HAVE_STRCASECMP
-/* Set to 1 if you have strtol() */
+/* Define to 1 if you have the `strdup' function. */
+#undef HAVE_STRDUP
+
+/* Define to 1 if you have the `strerror' function. */
+#undef HAVE_STRERROR
+
+/* Define to 1 if cpp supports the ANSI # stringizing operator. */
+#undef HAVE_STRINGIZE
+
+/* Define to 1 if you have the <strings.h> header file. */
+#undef HAVE_STRINGS_H
+
+/* Define to 1 if you have the <string.h> header file. */
+#undef HAVE_STRING_H
+
+/* Define to 1 if you have the `strtol' function. */
#undef HAVE_STRTOL
-/* Set to 1 if you have strtoul() */
+/* Define to 1 if you have the `strtoll' function. */
+#undef HAVE_STRTOLL
+
+/* Define to 1 if you have the `strtoq' function. */
+#undef HAVE_STRTOQ
+
+/* Define to 1 if you have the `strtoul' function. */
#undef HAVE_STRTOUL
-/* Set to 1 if you have strdup() */
-#undef HAVE_STRDUP
+/* Define to 1 if you have the `strtoull' function. */
+#undef HAVE_STRTOULL
-/* Set to 1 if you have random() */
-#undef HAVE_RANDOM
+/* Define to 1 if you have the `strtouq' function. */
+#undef HAVE_STRTOUQ
-/* Set to 1 if you have srandom() */
-#undef HAVE_SRANDOM
+/* Define to 1 if the system has the type `struct addrinfo'. */
+#undef HAVE_STRUCT_ADDRINFO
-/* The random() function is expected to yield values 0 .. MAX_RANDOM_VALUE */
-/* Currently, all known implementations yield 0..2^31-1, so we just hardwire
- * this constant. We could do a configure test if it proves to be necessary.
- * CAUTION: Think not to replace this with RAND_MAX. RAND_MAX defines the
- * maximum value of the older rand() function, which is often different from
- * --- and considerably inferior to --- random().
- */
-#define MAX_RANDOM_VALUE (0x7FFFFFFF)
+/* Define to 1 if the system has the type `struct cmsgcred'. */
+#undef HAVE_STRUCT_CMSGCRED
-/* Define if you have dlopen() */
-#undef HAVE_DLOPEN
+/* Define to 1 if the system has the type `struct fcred'. */
+#undef HAVE_STRUCT_FCRED
-/* Define if you have fdatasync() */
-#undef HAVE_FDATASYNC
+/* Define to 1 if the system has the type `struct sockaddr_un'. */
+#undef HAVE_STRUCT_SOCKADDR_UN
-/* Define if you have utime() */
-#undef HAVE_UTIME
+/* Define to 1 if the system has the type `struct sockcred'. */
+#undef HAVE_STRUCT_SOCKCRED
-/* Define if you have utimes() */
-#undef HAVE_UTIMES
+/* Define to 1 if `tm_zone' is member of `struct tm'. */
+#undef HAVE_STRUCT_TM_TM_ZONE
-/* Define if the standard header unistd.h declares fdatasync() */
-#undef HAVE_DECL_FDATASYNC
+/* Define to 1 if you have the <SupportDefs.h> header file. */
+#undef HAVE_SUPPORTDEFS_H
-/* Set to 1 if you have libz.a */
-#undef HAVE_LIBZ
+/* Define to 1 if you have the `sysconf' function. */
+#undef HAVE_SYSCONF
-/* Set to 1 if you have libreadline.a */
-#undef HAVE_LIBREADLINE
+/* Define to 1 if you have the syslog interface. */
+#undef HAVE_SYSLOG
-/* Set to 1 if your libreadline defines rl_completion_append_character */
-#undef HAVE_RL_COMPLETION_APPEND_CHARACTER
+/* Define to 1 if you have the <sys/ipc.h> header file. */
+#undef HAVE_SYS_IPC_H
-/* Set to 1 if you have rl_completion_matches */
-#undef HAVE_RL_COMPLETION_MATCHES
+/* Define to 1 if you have the <sys/poll.h> header file. */
+#undef HAVE_SYS_POLL_H
-/* Set to 1 if you have rl_filename_completion_function */
-#undef HAVE_RL_FILENAME_COMPLETION_FUNCTION
+/* Define to 1 if you have the <sys/pstat.h> header file. */
+#undef HAVE_SYS_PSTAT_H
-/* Set to 1 if you have replace_history_entry */
-#undef HAVE_REPLACE_HISTORY_ENTRY
+/* Define to 1 if you have the <sys/select.h> header file. */
+#undef HAVE_SYS_SELECT_H
-/* Set to 1 if you have getopt_long() (GNU long options) */
-#undef HAVE_GETOPT_LONG
+/* Define to 1 if you have the <sys/sem.h> header file. */
+#undef HAVE_SYS_SEM_H
-/* Set to 1 if you have union semun */
-#undef HAVE_UNION_SEMUN
+/* Define to 1 if you have the <sys/shm.h> header file. */
+#undef HAVE_SYS_SHM_H
-/* Set to 1 if you have struct cmsgcred */
-#undef HAVE_STRUCT_CMSGCRED
+/* Define to 1 if you have the <sys/socket.h> header file. */
+#undef HAVE_SYS_SOCKET_H
-/* Set to 1 if you have struct fcred */
-#undef HAVE_STRUCT_FCRED
+/* Define to 1 if you have the <sys/stat.h> header file. */
+#undef HAVE_SYS_STAT_H
-/* Set to 1 if you have struct sockcred */
-#undef HAVE_STRUCT_SOCKCRED
+/* Define to 1 if you have the <sys/types.h> header file. */
+#undef HAVE_SYS_TYPES_H
-/* Set to 1 if you have struct sockaddr_un */
-#undef HAVE_STRUCT_SOCKADDR_UN
+/* Define to 1 if you have the <sys/un.h> header file. */
+#undef HAVE_SYS_UN_H
-/* Set to 1 if you have struct addrinfo */
-#undef HAVE_STRUCT_ADDRINFO
+/* Define to 1 if you have the <termios.h> header file. */
+#undef HAVE_TERMIOS_H
-/* Set to 1 if you have krb5_ticket.enc_part2 */
-#undef HAVE_KRB5_TICKET_ENC_PART2
+/* Define to 1 if your `struct tm' has `tm_zone'. Deprecated, use
+ `HAVE_STRUCT_TM_TM_ZONE' instead. */
+#undef HAVE_TM_ZONE
-/* Set to 1 if you have krb5_ticket.client */
-#undef HAVE_KRB5_TICKET_CLIENT
+/* Define to 1 if you don't have `tm_zone' but do have the external array
+ `tzname'. */
+#undef HAVE_TZNAME
-/* Set to 1 if you have krb5_error.text.data */
-#undef HAVE_KRB5_ERROR_TEXT_DATA
+/* Define to 1 if the system has the type `uint64'. */
+#undef HAVE_UINT64
-/* Set to 1 if you have krb5_ticket.e_data */
-#undef HAVE_KRB5_ERROR_E_DATA
+/* Define to 1 if the system has the type `uint8'. */
+#undef HAVE_UINT8
-/* Set to 1 if type "long int" works and is 64 bits */
-#undef HAVE_LONG_INT_64
+/* Define to 1 if the system has the type `union semun'. */
+#undef HAVE_UNION_SEMUN
-/* Set to 1 if type "long long int" works and is 64 bits */
-#undef HAVE_LONG_LONG_INT_64
+/* Define to 1 if you have the <unistd.h> header file. */
+#undef HAVE_UNISTD_H
-/* Set to 1 if type "long long int" constants should be suffixed by LL */
-#undef HAVE_LL_CONSTANTS
+/* Define to 1 if you have the `utime' function. */
+#undef HAVE_UTIME
-/* Define this as the appropriate snprintf format for 64-bit ints, if any */
-#undef INT64_FORMAT
+/* Define to 1 if you have the `utimes' function. */
+#undef HAVE_UTIMES
-/*
- * We need a #define symbol for sizeof(Datum) for use in some #if tests.
- */
-#undef SIZEOF_DATUM
-
-/*
- * These must be defined as the alignment requirement (NOT the size) of
- * each of the basic C data types (except char, which we assume has align 1).
- * MAXIMUM_ALIGNOF is the largest alignment requirement for any C data type.
- * ALIGNOF_LONG_LONG_INT need only be defined if HAVE_LONG_LONG_INT_64 is.
- */
-#undef ALIGNOF_SHORT
-#undef ALIGNOF_INT
-#undef ALIGNOF_LONG
-#undef ALIGNOF_LONG_LONG_INT
-#undef ALIGNOF_DOUBLE
-#undef MAXIMUM_ALIGNOF
+/* Define to 1 if you have the <utime.h> header file. */
+#undef HAVE_UTIME_H
-/* Define as the type of the 3rd argument to accept() */
-#undef ACCEPT_TYPE_ARG3
+/* Define to 1 if you have the `vsnprintf' function. */
+#undef HAVE_VSNPRINTF
-/* Define if POSIX signal interface is available */
-#undef HAVE_POSIX_SIGNALS
+/* Define to 1 if you have the `waitpid' function. */
+#undef HAVE_WAITPID
-/* Define if you have the optreset variable */
-#undef HAVE_INT_OPTRESET
+/* Define to the appropriate snprintf format for 64-bit ints, if any. */
+#undef INT64_FORMAT
-/* Define if you have strtoll() */
-#undef HAVE_STRTOLL
+/* Define to build with Kerberos 4 support. (--with-krb4) */
+#undef KRB4
-/* Define if you have strtoq() */
-#undef HAVE_STRTOQ
+/* Define to build with Kerberos 5 support. (--with-krb5) */
+#undef KRB5
-/* Define if you have strtoull() */
-#undef HAVE_STRTOULL
+/* Define to the location of locale files. */
+#undef LOCALEDIR
-/* Define if you have strtouq() */
-#undef HAVE_STRTOUQ
+/* Define as the maximum alignment requirement of any C data type. */
+#undef MAXIMUM_ALIGNOF
-/* Define if you have atexit() */
-#undef HAVE_ATEXIT
+/* Define to the address where bug reports for this package should be sent. */
+#undef PACKAGE_BUGREPORT
-/* Define if you have on_exit() */
-#undef HAVE_ON_EXIT
+/* Define to the full name of this package. */
+#undef PACKAGE_NAME
-/* Define if you have syslog() */
-#undef HAVE_SYSLOG
+/* Define to the full name and version of this package. */
+#undef PACKAGE_STRING
-/* Define if you have poll() */
-#undef HAVE_POLL
+/* Define to the one symbol short name of this package. */
+#undef PACKAGE_TARNAME
-/* Define if the corresponding types are defined in standard headers */
-#undef HAVE_INT8
-#undef HAVE_UINT8
-#undef HAVE_INT64
-#undef HAVE_UINT64
-#undef HAVE_SIG_ATOMIC_T
+/* Define to the version of this package. */
+#undef PACKAGE_VERSION
-/* Define exactly one of these symbols to select semaphore implementation */
-#undef USE_NAMED_POSIX_SEMAPHORES
-#undef USE_UNNAMED_POSIX_SEMAPHORES
-#undef USE_SYSV_SEMAPHORES
+/* Define to the name of the PostgreSQL service principal in Kerberos.
+ (--with-krb-srvnam=NAME) */
+#undef PG_KRB_SRVNAM
-/* Define exactly one of these symbols to select shared-mem implementation */
-#undef USE_SYSV_SHARED_MEMORY
+/* PostgreSQL version */
+#undef PG_VERSION
+/* A string containing the version number, platform, and C compiler */
+#undef PG_VERSION_STR
-/*
- *------------------------------------------------------------------------
- * Part 4: pull in system-specific declarations.
- *
- * This is still configure's responsibility, because it picks where
- * the "pg_config_os.h" symlink points...
- *------------------------------------------------------------------------
- */
-
-/*
- * Pull in OS-specific declarations (using link created by configure)
- */
-
-#include "pg_config_os.h"
-
-
-/*
- *------------------------------------------------------------------------
- * Part 5: provide default declarations for various things that should be
- * provided by the system headers or the port-specific pg_config_os.h file,
- * but sometimes aren't.
- *
- * This must be last so that pg_config_os.h can override the defaults.
- * In particular, we must not pull in any system header files until we
- * have read pg_config_os.h (largefile support tends to break otherwise).
- *------------------------------------------------------------------------
- */
-
-#ifndef DLLIMPORT
-#define DLLIMPORT /* no special DLL markers on most ports */
-#endif
+/* The size of a `unsigned long', as computed by sizeof. */
+#undef SIZEOF_UNSIGNED_LONG
-/*
- * The following is used as the arg list for signal handlers. Any ports
- * that take something other than an int argument should override this in
- * their pg_config_os.h file. Note that variable names are required
- * because it is used in both the prototypes as well as the definitions.
- * Note also the long name. We expect that this won't collide with
- * other names causing compiler warnings.
- */
-
-#ifndef SIGNAL_ARGS
-#define SIGNAL_ARGS int postgres_signal_arg
-#endif
+/* Define to 1 if you have the ANSI C header files. */
+#undef STDC_HEADERS
-/*
- * Default "extern" declarations or macro substitutes for library routines.
- * When necessary, these routines are provided by files in src/port/.
- */
-#ifndef HAVE_FSEEKO
-#define fseeko(a, b, c) fseek((a), (b), (c))
-#define ftello(a) ftell((a))
-#endif
+/* Define to 1 if your <sys/time.h> declares `struct tm'. */
+#undef TM_IN_SYS_TIME
-#ifndef HAVE_ISINF
-extern int isinf(double x);
-#endif
+/* Define to 1 to build with assertion checks. (--enable-cassert) */
+#undef USE_ASSERT_CHECKING
-#ifndef HAVE_GETHOSTNAME
-extern int gethostname(char *name, int namelen);
-#endif
+/* Define to 1 if you want 64-bit integer timestamp and interval support.
+ (--enable-integer-datetimes) */
+#undef USE_INTEGER_DATETIMES
-#ifndef HAVE_INET_ATON
-# include <sys/types.h>
-# include <netinet/in.h>
-# include <arpa/inet.h>
-extern int inet_aton(const char *cp, struct in_addr * addr);
-#endif
+/* Define to select named POSIX semaphores. */
+#undef USE_NAMED_POSIX_SEMAPHORES
-/*
- * When there is no sigsetjmp, its functionality is provided by plain
- * setjmp. Incidentally, nothing provides setjmp's functionality in
- * that case.
- */
-#ifndef HAVE_SIGSETJMP
-# define sigjmp_buf jmp_buf
-# define sigsetjmp(x,y) setjmp(x)
-# define siglongjmp longjmp
-#endif
+/* Define to 1 to build with PAM support. (--with-pam) */
+#undef USE_PAM
-#ifndef HAVE_STRCASECMP
-extern int strcasecmp(char *s1, char *s2);
-#endif
+/* Define to build with (Open)SSL support. (--with-openssl) */
+#undef USE_SSL
-#ifndef HAVE_STRDUP
-extern char *strdup(char const *);
-#endif
+/* Define to select SysV-style semaphores. */
+#undef USE_SYSV_SEMAPHORES
-#ifndef HAVE_RANDOM
-extern long random(void);
-#endif
+/* Define to select SysV-style shared memory. */
+#undef USE_SYSV_SHARED_MEMORY
-#ifndef HAVE_SRANDOM
-extern void srandom(unsigned int seed);
-#endif
+/* Define to select unnamed POSIX semaphores. */
+#undef USE_UNNAMED_POSIX_SEMAPHORES
-#if defined(HAVE_FDATASYNC) && !HAVE_DECL_FDATASYNC
-extern int fdatasync(int fildes);
-#endif
+/* Number of bits in a file offset, on hosts where this is settable. */
+#undef _FILE_OFFSET_BITS
-/* If strtoq() exists, rename it to the more standard strtoll() */
-#if defined(HAVE_LONG_LONG_INT_64) && !defined(HAVE_STRTOLL) && defined(HAVE_STRTOQ)
-# define strtoll strtoq
-# define HAVE_STRTOLL 1
-#endif
+/* Define to 1 to make fseeko visible on some hosts (e.g. glibc 2.2). */
+#undef _LARGEFILE_SOURCE
-/* If strtouq() exists, rename it to the more standard strtoull() */
-#if defined(HAVE_LONG_LONG_INT_64) && !defined(HAVE_STRTOULL) && defined(HAVE_STRTOUQ)
-# define strtoull strtouq
-# define HAVE_STRTOULL 1
-#endif
+/* Define for large files, on AIX-style hosts. */
+#undef _LARGE_FILES
+
+/* Define to empty if `const' does not conform to ANSI C. */
+#undef const
+/* Define as `__inline' if that's what the C compiler calls it, or to nothing
+ if it is not supported. */
+#undef inline
-#endif /* PG_CONFIG_H */
+/* Define to empty if the C compiler does not understand signed types. */
+#undef signed
+
+/* Define to empty if the keyword `volatile' does not work. Warning: valid
+ code using `volatile' can become incorrect without. Disable with care. */
+#undef volatile
diff --git a/src/include/pg_config_manual.h b/src/include/pg_config_manual.h
new file mode 100644
index 00000000000..1629638ebed
--- /dev/null
+++ b/src/include/pg_config_manual.h
@@ -0,0 +1,212 @@
+/*------------------------------------------------------------------------
+ * PostgreSQL manual configuration settings
+ *
+ * This file contains various configuration symbols and limits. In
+ * all cases, changing them is only useful in very rare situations or
+ * for developers. If you edit any of these, be sure to do a *full*
+ * rebuild (and an initdb if noted).
+ *
+ * $Id: pg_config_manual.h,v 1.1 2003/04/06 22:45:23 petere Exp $
+ *------------------------------------------------------------------------
+ */
+
+/*
+ * Size of a disk block --- this also limits the size of a tuple. You
+ * can set it bigger if you need bigger tuples (although TOAST should
+ * reduce the need to have large tuples, since fields can be spread
+ * across multiple tuples).
+ *
+ * BLCKSZ must be a power of 2. The maximum possible value of BLCKSZ
+ * is currently 2^15 (32768). This is determined by the 15-bit widths
+ * of the lp_off and lp_len fields in ItemIdData (see
+ * include/storage/itemid.h).
+ *
+ * Changing BLCKSZ requires an initdb.
+ */
+#define BLCKSZ 8192
+
+/*
+ * RELSEG_SIZE is the maximum number of blocks allowed in one disk
+ * file. Thus, the maximum size of a single file is RELSEG_SIZE *
+ * BLCKSZ; relations bigger than that are divided into multiple files.
+ *
+ * RELSEG_SIZE * BLCKSZ must be less than your OS' limit on file size.
+ * This is often 2 GB or 4GB in a 32-bit operating system, unless you
+ * have large file support enabled. By default, we make the limit 1
+ * GB to avoid any possible integer-overflow problems within the OS.
+ * A limit smaller than necessary only means we divide a large
+ * relation into more chunks than necessary, so it seems best to err
+ * in the direction of a small limit. (Besides, a power-of-2 value
+ * saves a few cycles in md.c.)
+ *
+ * Changing RELSEG_SIZE requires an initdb.
+ */
+#define RELSEG_SIZE (0x40000000 / BLCKSZ)
+
+/*
+ * Maximum number of columns in an index and maximum number of
+ * arguments to a function. They must be the same value.
+ *
+ * The minimum value is 8 (index creation uses 8-argument functions).
+ * There is no specific upper limit, although large values will waste
+ * system-table space and processing time.
+ *
+ * Changing these requires an initdb.
+ */
+#define INDEX_MAX_KEYS 32
+#define FUNC_MAX_ARGS INDEX_MAX_KEYS
+
+/*
+ * Define this to make libpgtcl's "pg_result -assign" command process
+ * C-style backslash sequences in returned tuple data and convert
+ * PostgreSQL array values into Tcl lists. CAUTION: This conversion
+ * is *wrong* unless you install the routines in
+ * contrib/string/string_io to make the server produce C-style
+ * backslash sequences in the first place.
+ */
+/* #define TCL_ARRAYS */
+
+/*
+ * User locks are handled totally on the application side as long term
+ * cooperative locks which extend beyond the normal transaction
+ * boundaries. Their purpose is to indicate to an application that
+ * someone is `working' on an item. Define this flag to enable user
+ * locks. You will need the loadable module user-locks.c to use this
+ * feature.
+ */
+#define USER_LOCKS
+
+/*
+ * Define this if you want psql to _always_ ask for a username and a
+ * password for password authentication.
+ */
+/* #define PSQL_ALWAYS_GET_PASSWORDS */
+
+/*
+ * Define this if you want to allow the lo_import and lo_export SQL
+ * functions to be executed by ordinary users. By default these
+ * functions are only available to the Postgres superuser. CAUTION:
+ * These functions are SECURITY HOLES since they can read and write
+ * any file that the PostgreSQL server has permission to access. If
+ * you turn this on, don't say we didn't warn you.
+ */
+/* #define ALLOW_DANGEROUS_LO_FUNCTIONS */
+
+/*
+ * MAXPGPATH: standard size of a pathname buffer in PostgreSQL (hence,
+ * maximum usable pathname length is one less).
+ *
+ * We'd use a standard system header symbol for this, if there weren't
+ * so many to choose from: MAXPATHLEN, MAX_PATH, PATH_MAX are all
+ * defined by different "standards", and often have different values
+ * on the same platform! So we just punt and use a reasonably
+ * generous setting here.
+ */
+#define MAXPGPATH 1024
+
+/*
+ * DEFAULT_MAX_EXPR_DEPTH: default value of max_expr_depth SET variable.
+ */
+#define DEFAULT_MAX_EXPR_DEPTH 10000
+
+/*
+ * PG_SOMAXCONN: maximum accept-queue length limit passed to
+ * listen(2). You'd think we should use SOMAXCONN from
+ * <sys/socket.h>, but on many systems that symbol is much smaller
+ * than the kernel's actual limit. In any case, this symbol need be
+ * twiddled only if you have a kernel that refuses large limit values,
+ * rather than silently reducing the value to what it can handle
+ * (which is what most if not all Unixen do).
+ */
+#define PG_SOMAXCONN 10000
+
+/*
+ * You can try changing this if you have a machine with bytes of
+ * another size, but no guarantee...
+ */
+#define BITS_PER_BYTE 8
+
+/*
+ * Define this if your operating system supports AF_UNIX family
+ * sockets.
+ */
+#if !defined(__QNX__) && !defined(__BEOS__)
+# define HAVE_UNIX_SOCKETS 1
+#endif
+
+/*
+ * This is the default directory in which AF_UNIX socket files are
+ * placed. Caution: changing this risks breaking your existing client
+ * applications, which are likely to continue to look in the old
+ * directory. But if you just hate the idea of sockets in /tmp,
+ * here's where to twiddle it. You can also override this at runtime
+ * with the postmaster's -k switch.
+ */
+#define DEFAULT_PGSOCKET_DIR "/tmp"
+
+/*
+ * Defining this will make float4 and float8 operations faster by
+ * suppressing overflow/underflow checks.
+ */
+/* #define UNSAFE_FLOATS */
+
+/*
+ * The random() function is expected to yield values between 0 and
+ * MAX_RANDOM_VALUE. Currently, all known implementations yield
+ * 0..2^31-1, so we just hardwire this constant. We could do a
+ * configure test if it proves to be necessary. CAUTION: Think not to
+ * replace this with RAND_MAX. RAND_MAX defines the maximum value of
+ * the older rand() function, which is often different from --- and
+ * considerably inferior to --- random().
+ */
+#define MAX_RANDOM_VALUE (0x7FFFFFFF)
+
+
+/*
+ *------------------------------------------------------------------------
+ * The following symbols are for enabling debugging code, not for
+ * controlling user-visible features or resource limits.
+ *------------------------------------------------------------------------
+ */
+
+/*
+ * Define this to cause pfree()'d memory to be cleared immediately, to
+ * facilitate catching bugs that refer to already-freed values. XXX
+ * Right now, this gets defined automatically if --enable-cassert. In
+ * the long term it probably doesn't need to be on by default.
+ */
+#ifdef USE_ASSERT_CHECKING
+#define CLOBBER_FREED_MEMORY
+#endif
+
+/*
+ * Define this to check memory allocation errors (scribbling on more
+ * bytes than were allocated). Right now, this gets defined
+ * automatically if --enable-cassert. In the long term it probably
+ * doesn't need to be on by default.
+ */
+#ifdef USE_ASSERT_CHECKING
+#define MEMORY_CONTEXT_CHECKING
+#endif
+
+/*
+ * Define this to force all parse and plan trees to be passed through
+ * copyObject(), to facilitate catching errors and omissions in
+ * copyObject().
+ */
+/* #define COPY_PARSE_PLAN_TREES */
+
+/*
+ * Enable debugging print statements for lock-related operations.
+ */
+/* #define LOCK_DEBUG */
+
+/*
+ * Other debug #defines (documentation, anyone?)
+ */
+/* #define IPORTAL_DEBUG */
+/* #define HEAPDEBUGALL */
+/* #define ISTRATDEBUG */
+/* #define ACLDEBUG */
+/* #define RTDEBUG */
+/* #define GISTDEBUG */
diff --git a/src/include/postgres.h b/src/include/postgres.h
index 9d7ad9bbec3..3d2da911d27 100644
--- a/src/include/postgres.h
+++ b/src/include/postgres.h
@@ -10,7 +10,7 @@
* Portions Copyright (c) 1996-2002, PostgreSQL Global Development Group
* Portions Copyright (c) 1995, Regents of the University of California
*
- * $Id: postgres.h,v 1.62 2002/10/18 20:33:57 tgl Exp $
+ * $Id: postgres.h,v 1.63 2003/04/06 22:45:23 petere Exp $
*
*-------------------------------------------------------------------------
*/
@@ -130,6 +130,7 @@ typedef struct varattrib
*/
typedef unsigned long Datum; /* XXX sizeof(long) >= sizeof(void *) */
+#define SIZEOF_DATUM SIZEOF_UNSIGNED_LONG
typedef Datum *DatumPtr;
#define GET_1_BYTE(datum) (((Datum) (datum)) & 0x000000ff)
diff --git a/src/backend/catalog/genbki.sh b/src/backend/catalog/genbki.sh
index 2fbb84494ca..901c33f1787 100644
--- a/src/backend/catalog/genbki.sh
+++ b/src/backend/catalog/genbki.sh
@@ -10,7 +10,7 @@
#
#
# IDENTIFICATION
-# $Header: /cvsroot/pgsql/src/backend/catalog/Attic/genbki.sh,v 1.28 2002/07/31 17:19:51 tgl Exp $
+# $Header: /cvsroot/pgsql/src/backend/catalog/Attic/genbki.sh,v 1.29 2003/04/06 22:45:22 petere Exp $
#
# NOTES
# non-essential whitespace is removed from the generated file.
@@ -66,7 +66,7 @@ do
echo " $CMDNAME [ -D define [...] ] [ -I dir ] --set-version=VERSION -o prefix files..."
echo
echo "Options:"
- echo " -I path to postgres_ext.h and pg_config.h files"
+ echo " -I path to postgres_ext.h and pg_config_manual.h files"
echo " -o prefix of output files"
echo " --set-version PostgreSQL version number for initdb cross-check"
echo
@@ -126,11 +126,11 @@ for dir in $INCLUDE_DIRS; do
fi
done
-# Get INDEX_MAX_KEYS from pg_config.h
+# Get INDEX_MAX_KEYS from pg_config_manual.h
# (who needs consistency?)
for dir in $INCLUDE_DIRS; do
- if [ -f "$dir/pg_config.h" ]; then
- INDEXMAXKEYS=`grep '^#define[ ]*INDEX_MAX_KEYS' $dir/pg_config.h | $AWK '{ print $3 }'`
+ if [ -f "$dir/pg_config_manual.h" ]; then
+ INDEXMAXKEYS=`grep '^#define[ ]*INDEX_MAX_KEYS' $dir/pg_config_manual.h | $AWK '{ print $3 }'`
break
fi
done
@@ -152,9 +152,10 @@ for dir in $INCLUDE_DIRS; do
done
export BKIOBJECTID
# NOTE: we assume here that FUNC_MAX_ARGS has the same value as INDEX_MAX_KEYS,
# and don't read it separately from pg_config.h. This is OK because both of them
# must be equal to the length of oidvector.
INDEXMAXKEYS2=`expr $INDEXMAXKEYS '*' 2` || exit
INDEXMAXKEYS4=`expr $INDEXMAXKEYS '*' 4` || exit
@@ -152,9 +152,10 @@ for dir in $INCLUDE_DIRS; do
done
export BKIOBJECTID
-# NOTE: we assume here that FUNC_MAX_ARGS has the same value as INDEX_MAX_KEYS,
-# and don't read it separately from pg_config.h. This is OK because both of them
-# must be equal to the length of oidvector.
+# NOTE: we assume here that FUNC_MAX_ARGS has the same value as
+# INDEX_MAX_KEYS, and don't read it separately from
+# pg_config_manual.h. This is OK because both of them must be equal
+# to the length of oidvector.
INDEXMAXKEYS2=`expr $INDEXMAXKEYS '*' 2` || exit
INDEXMAXKEYS4=`expr $INDEXMAXKEYS '*' 4` || exit